SELECT
  'dynamic' as component,
  sqlpage.run_sql('cookie.sql') AS properties
;

SELECT
  'dynamic' as component,
  sqlpage.run_sql('nav.sql') AS properties
;

SELECT
  'table' AS component,
  TRUE AS search,
  TRUE AS striped_rows,
  TRUE AS small,
  'Notice' AS markdown
;

DROP TABLE IF EXISTS sqlpage_groups;
CREATE TEMPORARY TABLE IF NOT EXISTS sqlpage_groups AS (
SELECT
    "Products",
    "Categories",
    COALESCE("group", "Groups"||'') "Group"
FROM (SELECT
  count(DISTINCT p.id) AS "Products",
  count(DISTINCT c.id) AS "Categories",
  count(DISTINCT g.id) AS "Groups",
  p.name AS "product",
  c.name AS "category",
  g.name AS "group"
FROM products p
JOIN categories c ON p.category_id = c.id
JOIN groups g ON c.group_id = g.id
JOIN sqlpage_options op ON op.type = 'product' AND p.name = op.name
JOIN sqlpage_options oc ON oc.type = 'category' AND c.name = oc.name
JOIN sqlpage_options og ON og.type = 'group' AND g.name = og.name
WHERE COALESCE(op.selected, oc.selected, og.selected, TRUE)
AND
  COALESCE(op.selected, oc.selected, og.selected, TRUE)
AND
  op.session = sqlpage.cookie('session')
AND
  oc.session = sqlpage.cookie('session')
AND
  og.session = sqlpage.cookie('session')
GROUP BY ROLLUP (g.name, c.name, p.name)
ORDER BY product, category, "group") q
WHERE q.category IS NULL
);
SELECT * FROM sqlpage_groups;

SELECT 
  '# No Data' AS "Notice"
WHERE NOT EXISTS(SELECT * FROM sqlpage_groups LIMIT 1);
