SELECT 'shell' AS component,
  'dark' AS theme,
  COALESCE($tab, 'Transactions') AS title
;
CREATE TABLE IF NOT EXISTS sqlpage_options(
  session text,
  "type" text,
  name text,
  selected boolean
);
DELETE FROM sqlpage_options
WHERE
  session = sqlpage.cookie('session')
AND (
    $clear = 'Clear'
  OR
    $products IS NOT NULL
  OR
    $categories IS NOT NULL
  OR
    $groups IS NOT NULL
);

CREATE TEMPORARY TABLE IF NOT EXISTS state(update boolean);
TRUNCATE state;
INSERT INTO state(update)
SELECT NOT EXISTS (SELECT 1 FROM sqlpage_options WHERE session = sqlpage.cookie('session'));

INSERT INTO sqlpage_options
SELECT
  sqlpage.cookie('session'),
  UNNEST(ARRAY['product', 'category', 'group']) AS "type",
  UNNEST(q.name) AS name,
  UNNEST(selected)
FROM (
  SELECT
    ARRAY[p.name, c.name, g.name] AS name,
    ARRAY[
      CASE WHEN $products IS NOT NULL THEN fp.v IS NOT NULL ELSE NULL END,
      CASE WHEN $categories IS NOT NULL THEN fc.v IS NOT NULL ELSE NULL END,
      CASE WHEN $groups IS NOT NULL THEN fg.v IS NOT NULL ELSE NULL END
    ]
  FROM products p
  LEFT JOIN json_array_elements($products::json) fp(v)
  ON p.name = fp.v#>>'{}'
  JOIN categories c ON p.category_id = c.id
  LEFT JOIN json_array_elements($categories::json) fc(v)
  ON c.name = fc.v#>>'{}'
  JOIN groups g ON c.group_id = g.id
  LEFT JOIN json_array_elements($groups::json) fg(v)
  ON g.name = fg.v#>>'{}'
  WHERE (
    (p.name = fp.v#>>'{}' OR $products IS NULL)
  AND
    (c.name = fc.v#>>'{}' OR $categories IS NULL)
  AND
    (g.name = fg.v#>>'{}' OR $groups IS NULL)
  AND
    EXISTS (SELECT 1 FROM state WHERE update IS TRUE)
  )
) q(name, selected)
UNION
SELECT
  sqlpage.cookie('session'),
  'group',
  f.v#>>'{}',
  TRUE
FROM json_array_elements($groups::json) f(v)
LEFT JOIN groups g ON g.name = f.v#>>'{}'
WHERE g.name is NULL
  AND
    EXISTS (SELECT 1 FROM state WHERE update IS TRUE)
UNION
SELECT
  sqlpage.cookie('session'),
  'category',
  f.v#>>'{}',
  TRUE
FROM json_array_elements($categories::json) f(v)
LEFT JOIN categories c ON c.name = f.v#>>'{}'
WHERE c.name is NULL
  AND
    EXISTS (SELECT 1 FROM state WHERE update IS TRUE)
UNION
SELECT
  sqlpage.cookie('session'),
  'product',
  f.v#>>'{}',
  TRUE
FROM json_array_elements($products::json) f(v)
LEFT JOIN products p ON p.name = f.v#>>'{}'
WHERE p.name is NULL
  AND
    EXISTS (SELECT 1 FROM state WHERE update IS TRUE)
;

--SELECT
--  'text' AS component,
--  '<style>
--.nav { pointer-events: none }
--.navbar { display: none }
--input[value=Products].form-control,
--input[value=Categories].form-control,
--input[value=Groups].form-control,
--input[value=Transactions].form-control
--{
--    color: var(--tblr-secondary);
--    border-right: unset;
--    border-top: unset;
--    border-left: unset;
--}
--input[value='||CASE
--  WHEN $tab IN ('Products', 'Categories', 'Groups')
--  THEN $tab ELSE 'Transactions'
--END||'].form-control
--{
--    color: var(--tblr-primary);
--    border-right: unset;
--    border-top: unset;
--    border-left: unset;
--    border-bottom-color: var(--tblr-primary);
--    border-bottom-width: 2px;
--}
--</style>' AS html
--;
  
SELECT
  'tab' AS component,
  TRUE AS center
;

SELECT
 'products' AS id,
 'Products' AS title,
 sqlpage.path() = '/products.sql' AS active,
 'products.sql' AS link
;
SELECT
 'categories' AS id,
 'Categories' AS title,
 sqlpage.path() = '/categories.sql' AS active,
 'categories.sql' AS link
;
SELECT
 'groups' AS id,
 'Groups' AS title,
 sqlpage.path() = '/groups.sql' AS active,
 'groups.sql' AS link
;
SELECT
 'transactions' AS id,
 'Transactions' AS title,
 sqlpage.path() = '/transactions.sql' AS active,
 'transactions.sql' AS link
;

SELECT
  'form' AS component,
  'filter' AS id,
  'get' AS method,
  '' AS title,
  'Apply' AS validate
;

SELECT
  'path' AS name,
  '' AS label,
  sqlpage.path() AS value,
  'hidden' AS type
;

--SELECT
--  'tab' AS name,
--  'Products' AS value,
--  '' AS label,
--  3 AS width,
--  'submit' AS type,
--  'transactions.sql' AS formaction
--;
--SELECT
--  'tab' AS name,
--  'Categories' AS value,
--  '' AS label,
--  3 AS width,
--  'submit' AS type,
--  'transactions.sql' AS formaction
--;
--SELECT
--  'tab' AS name,
--  'Groups' AS value,
--  '' AS label,
--  3 AS width,
--  'submit' AS type,
--  'transactions.sql' AS formaction
--;
--SELECT
--  'tab' AS name,
--  'Transactions' AS value,
--  '' AS label,
--  3 AS width,
--  'submit' AS type,
--  'transactions.sql' AS formaction
--;

SELECT
  'products[]' AS name,
  'Product' AS label,
  4 AS width,
  'select' AS "type",
  TRUE AS dropdown,
  TRUE AS multiple,
  json_agg(json_build_object(
    'label', o.name,
    'value', o.name,
    'selected', COALESCE(o.selected, FALSE)
  ) ORDER BY o.name) AS options
FROM sqlpage_options o
WHERE
  o.type = 'product'
AND
  o.session = sqlpage.cookie('session')
;
SELECT
  'categories[]' AS name,
  'Categories' AS label,
  4 AS width,
  'select' AS "type",
  TRUE AS dropdown,
  TRUE AS multiple,
  json_agg(json_build_object(
    'label', o.name,
    'value', o.name,
    'selected', COALESCE(o.selected, FALSE)
  ) ORDER BY o.name) AS options
FROM sqlpage_options o
WHERE
  o.type = 'category'
AND
  o.session = sqlpage.cookie('session')
;
SELECT
  'groups[]' AS name,
  'Groups' AS label,
  4 AS width,
  'select' AS "type",
  TRUE AS dropdown,
  TRUE AS multiple,
  json_agg(json_build_object(
    'label', o.name,
    'value', o.name,
    'selected', COALESCE(o.selected, FALSE)
  ) ORDER BY o.name) AS options
FROM sqlpage_options o
WHERE
  o.type = 'group'
AND
  o.session = sqlpage.cookie('session')
;
SELECT
  'clear' AS name,
  'Clear' AS value,
  '' AS label,
  1 AS width,
  'submit' AS type,
  'clear.sql?page='||sqlpage.path() AS formaction
;

